References — Scrapple documentation

### Navigation

- index
- modules |
- previous |
- Scrapple documentation »

# References

[1] | Kei Kanaoka, Yotaro Fujii and Motomichi Toyama. Ducky: A Data Extraction System for Various Structured Web Documents. In Proceedings of the 18th International Database Engineering & Applications Symposium, IDEAS ’14, pages 342-347, New York, NY, USA, 2014. ACM

[2] | Scrapy: A fast and powerful scraping and web crawling framework.[Online] Available:https://www.scrapy.org

[3] | T.Furche, G. Gottlob, G. Grasso, C. Schallhart, and A. Sellers. Oxpath: A language for scalable data extraction, automation, and crawling on the deep web. The VLDB Journal, 22(1):47–72, Feb. 2013

[4] | V.Crescenzi, P. Merialdo, and D. Qiu. Alfred: Crowd assisted data extraction. In Proceedings of the 22Nd International Conference on World Wide Web Companion, WWW ’13 Companion, pages 297–300, Republic and Canton of Geneva, Switzerland, 2013. International World Wide Web Conferences Steering Committee.

[5] | F.Kokkoras, K. Ntonas, and N. Bassiliades. Deixto: A web data extraction suite. In Proceedings of the 6th Balkan Conference in Informatics, BCI ’13, pages 9–12, New York, NY, USA, 2013. ACM.

[6] | lxml - Processing XML and HTML with Python [Online]. Available: http://lxml.de/

[7] | Elements and Element Trees [Online]. Available: http://effbot.org/zone/element.htm

[8] | XPath support in ElementTree[Online]. Available: http://effbot.org/zone/element-xpath.htm

[9] | XML Path language(XPath)[Online]. Available: http://www.w3.org/TR/xpath/

[10] | Selectors[Online]. Available: http://www.w3.org/TR/CSS21/selector.html

### Navigation

- index
- modules |
- previous |
- Scrapple documentation »